@@ -1,9 +1,8 @@
 
-__version__ = "1.4.0"
+__version__ = "1.7.0"
 docs = r"https://alexlib.readthedocs.io/en/latest/"
 git = r"https://github.com/thisismygitrepo/alexlib"
 release_notes = """
 
-Cleaned deeplearning_torch module. Removed Assert module.
-
+Added tutorial
 """
